@@ -378,6 +378,43 @@ const unsigned char iso8859_10_unicode[ISO8859_UNICODE_TABLE_MAX][2] = {
 };
 
 
+/* ISO-8859-11(Windows-874)  0x80-0xFF */
+const unsigned char iso8859_11_unicode[ISO8859_UNICODE_TABLE_MAX][2] = {
+    {0x20, 0xAC}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x20, 0x26}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x20, 0x18}, {0x20, 0x19}, {0x20, 0x1C},
+    {0x20, 0x1D}, {0x20, 0x22}, {0x20, 0x13}, {0x20, 0x14},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0xA0}, {0x0E, 0x01}, {0x0E, 0x02}, {0x0E, 0x03},
+    {0x0E, 0x04}, {0x0E, 0x05}, {0x0E, 0x06}, {0x0E, 0x07},
+    {0x0E, 0x08}, {0x0E, 0x09}, {0x0E, 0x0A}, {0x0E, 0x0B},
+    {0x0E, 0x0C}, {0x0E, 0x0D}, {0x0E, 0x0E}, {0x0E, 0x0F},
+    {0x0E, 0x10}, {0x0E, 0x11}, {0x0E, 0x12}, {0x0E, 0x13},
+    {0x0E, 0x14}, {0x0E, 0x15}, {0x0E, 0x16}, {0x0E, 0x17},
+    {0x0E, 0x18}, {0x0E, 0x19}, {0x0E, 0x1A}, {0x0E, 0x1B},
+    {0x0E, 0x1C}, {0x0E, 0x1D}, {0x0E, 0x1E}, {0x0E, 0x1F},
+    {0x0E, 0x20}, {0x0E, 0x21}, {0x0E, 0x22}, {0x0E, 0x23},
+    {0x0E, 0x24}, {0x0E, 0x25}, {0x0E, 0x26}, {0x0E, 0x27},
+    {0x0E, 0x28}, {0x0E, 0x29}, {0x0E, 0x2A}, {0x0E, 0x2B},
+    {0x0E, 0x2C}, {0x0E, 0x2D}, {0x0E, 0x2E}, {0x0E, 0x2F},
+    {0x0E, 0x30}, {0x0E, 0x31}, {0x0E, 0x32}, {0x0E, 0x33},
+    {0x0E, 0x34}, {0x0E, 0x35}, {0x0E, 0x36}, {0x0E, 0x37},
+    {0x0E, 0x38}, {0x0E, 0x39}, {0x0E, 0x3A}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x0E, 0x3F},
+    {0x0E, 0x40}, {0x0E, 0x41}, {0x0E, 0x42}, {0x0E, 0x43},
+    {0x0E, 0x44}, {0x0E, 0x45}, {0x0E, 0x46}, {0x0E, 0x47},
+    {0x0E, 0x48}, {0x0E, 0x49}, {0x0E, 0x4A}, {0x0E, 0x4B},
+    {0x0E, 0x4C}, {0x0E, 0x4D}, {0x0E, 0x4E}, {0x0E, 0x4F},
+    {0x0E, 0x50}, {0x0E, 0x51}, {0x0E, 0x52}, {0x0E, 0x53},
+    {0x0E, 0x54}, {0x0E, 0x55}, {0x0E, 0x56}, {0x0E, 0x57},
+    {0x0E, 0x58}, {0x0E, 0x59}, {0x0E, 0x5A}, {0x0E, 0x5B},
+    {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F}
+};
+
+
 /* ISO-8859-13  0x80-0xFF */
 const unsigned char iso8859_13_unicode[ISO8859_UNICODE_TABLE_MAX][2] = {
     {0x00, 0x80}, {0x00, 0x81}, {0x00, 0x82}, {0x00, 0x83},
